@@ -36,7 +36,7 @@ static int is_pkg_in_pkg_vec(pkg_vec_t * vec, pkg_t * pkg);
 static int pkg_installed_and_constraint_satisfied(pkg_t *pkg, void *cdata)
 {
      depend_t *depend = (depend_t *)cdata;
-     if (pkg->state_status == SS_INSTALLED && version_constraints_satisfied(depend, pkg))
+     if ((pkg->state_status == SS_INSTALLED || pkg->state_status == SS_UNPACKED) && version_constraints_satisfied(depend, pkg))
 	  return 1;
      else
 	  return 0;
@@ -136,13 +136,26 @@ int pkg_hash_fetch_unsatisfied_dependencies(ipkg_conf_t *conf, pkg_t * pkg,
 										pkg_scout, 
 										tmp_vec,
 										&newstuff);
-				   if (rc == 0 && newstuff == NULL) {
-					/* mark this one for installation */
-					ipkg_message(conf, IPKG_NOTICE, "Adding satisfier for greedy dependence: %s\n", pkg_scout->name);
-					pkg_vec_insert(unsatisfied, pkg_scout);
+				   if (newstuff == NULL) {
+					int i;
+					int ok = 1;
+					for (i = 0; i < rc; i++) {
+					    pkg_t *p = tmp_vec->pkgs[i];
+					    if (p->state_want == SW_INSTALL)
+						continue;
+					    ipkg_message(conf, IPKG_DEBUG, "not installing %s due to requirement for %s\n", pkg_scout->name, p->name);
+					    ok = 0;
+					    break;
+					}
+					pkg_vec_free (tmp_vec);
+					if (ok) {
+					    /* mark this one for installation */
+					    ipkg_message(conf, IPKG_NOTICE, "Adding satisfier for greedy dependence: %s\n", pkg_scout->name);
+					    pkg_vec_insert(unsatisfied, pkg_scout);
+					}
 				   } else  {
-					if (newstuff)
-					     free (newstuff);
+					ipkg_message(conf, IPKG_DEBUG, "not installing %s due to broken depends %s\n", pkg_scout->name, newstuff);
+					free (newstuff);
 				   }
 			      }
 			 }
@@ -160,7 +173,7 @@ int pkg_hash_fetch_unsatisfied_dependencies(ipkg_conf_t *conf, pkg_t * pkg,
 	       pkg_t *satisfying_pkg = 
 		    pkg_hash_fetch_best_installation_candidate(conf, satisfying_apkg, 
 							       pkg_installed_and_constraint_satisfied, 
-							       dependence_to_satisfy);
+							       dependence_to_satisfy, 1);
 	       ipkg_message(conf, IPKG_DEBUG, "%s:%d: satisfying_pkg=%p\n", __FILE__, __LINE__, satisfying_pkg);
 	       if (satisfying_pkg != NULL) {
 		    found = 1;
@@ -178,7 +191,7 @@ int pkg_hash_fetch_unsatisfied_dependencies(ipkg_conf_t *conf, pkg_t * pkg,
 		    pkg_t *satisfying_pkg = 
 			 pkg_hash_fetch_best_installation_candidate(conf, satisfying_apkg, 
 								    pkg_constraint_satisfied, 
-								    dependence_to_satisfy);
+								    dependence_to_satisfy, 1);
 
 		    /* user request overrides package recommendation */
 		    if (satisfying_pkg != NULL
